DROP FUNCTION AVL_PESQUISA_OPINIAO
/

DROP TYPE AVL_PESQUISA_OPINIAO_TABLE
/

DROP TYPE AVL_PESQUISA_OPINIAO_TYPE
/

CREATE TYPE AVL_PESQUISA_OPINIAO_TYPE AS OBJECT
  (NRORG NUMBER,
   -- FILIAL
   CDFILIAL VARCHAR2(4), 
   NMFILIAL VARCHAR2(40),
   NMSUPERVISOR VARCHAR2(40),
   
   -- QUESTIONRIO MODELO
   NRPADRAVALIACAO NUMBER,
   NMPADRAVALIACAO VARCHAR2(100),
   
   -- QUESTO
   NRQUESTAO NUMBER,
   TXQUESTAO VARCHAR2(4000),
   TXCOMPLEMENTOQUESTAO VARCHAR2(250),
   NRTEMAANALISE NUMBER,
   NMTEMAANALISE VARCHAR2(100),
   SGTEMAANALISE VARCHAR2(10),
   TXPALAVRACHAVE VARCHAR2(4000),
   
   -- LOCAL DE AVALIAO
   NRLOCALAVALIACAO NUMBER,
   NMLOCALAVALIACAO VARCHAR2(100),
   SGLOCALAVALIACAO VARCHAR2(10),
   
   -- ITEM DE AVALIAO
   NRITEMAVALIACAO NUMBER,
   NMITEMAVALIACAO VARCHAR2(100),
   SGITEMAVALIACAO VARCHAR2(10),
   
   -- AVALIAO
   NRAVALIACAO NUMBER,
   DTREFEAVALIACAO DATE,
   DTMETAMES DATE,
   QTPREVPARTICAVAL FLOAT,
   IDSITUACAOAVALIACAO VARCHAR2(30),
   DTINCLUSAO DATE,
   CDOPERINCLUSAO VARCHAR2(12),
   
   -- META POR MS
   METAPEPARTICIPACAO FLOAT,
   METAPESATISFACAO FLOAT,
   
   -- AVALIAO   
   QTREALPARTICAVAL FLOAT,
   VRMAIORPESORESPOSTA FLOAT,
   VRPESOTOTALAVALIACAO FLOAT,
   VRPESOIDEALAVALIACAO FLOAT,

   VRPEPARTICIPACAO FLOAT,
   VRPESATISFACAO FLOAT,

   RESPOSTAS VARCHAR2(4000),
   
   RESPOSTA1 VARCHAR2(4000),
   RESPOSTA2 VARCHAR2(4000),
   RESPOSTA3 VARCHAR2(4000),
   RESPOSTA4 VARCHAR2(4000),
   RESPOSTA5 VARCHAR2(4000),

   VRPESORESPOSTA1 FLOAT,
   VRPESORESPOSTA2 FLOAT,
   VRPESORESPOSTA3 FLOAT,
   VRPESORESPOSTA4 FLOAT,
   VRPESORESPOSTA5 FLOAT,

   QTDE_RESPOSTA1 FLOAT,
   QTDE_RESPOSTA2 FLOAT,
   QTDE_RESPOSTA3 FLOAT,
   QTDE_RESPOSTA4 FLOAT,
   QTDE_RESPOSTA5 FLOAT)
/

CREATE TYPE AVL_PESQUISA_OPINIAO_TABLE AS TABLE OF AVL_PESQUISA_OPINIAO_TYPE
/

CREATE OR REPLACE
FUNCTION AVL_PESQUISA_OPINIAO
  (P_NRORG IN ORGANIZACAO.NRORG%TYPE,
   P_CDGRUPFILI IN GRUPFILI.CDGRUPFILI%TYPE,
   P_CDFILIAL IN FILIAL.CDFILIAL%TYPE,
   P_DATA_INICIAL IN DATE DEFAULT SYSDATE,
   P_DATA_FINAL IN DATE DEFAULT SYSDATE,
   P_SITUACAO_AVALIACAO IN VARCHAR2 DEFAULT 'T')
RETURN AVL_PESQUISA_OPINIAO_TABLE PIPELINED IS
   V_PENDENTE VARCHAR2(30);
   V_CONCLUIDA VARCHAR2(30);
   V_CANCELADA VARCHAR2(30);
   OUT_RECORD AVL_PESQUISA_OPINIAO_TYPE := AVL_PESQUISA_OPINIAO_TYPE
   (NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
    NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
    NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
    NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
   CURSOR C_AVALIACAO IS
      (SELECT AV.NRORG,
              -- FILIAL      
              AV.CDFILIAL,
              AV.NMFILIAL,
              AV.NMSUPERVISOR,
   
              -- QUESTIONRIO MODELO
              AV.NRPADRAVALIACAO,
              AV.NMPADRAVALIACAO,
   
              -- QUESTO
              AV.NRQUESTAO,
              AV.TXQUESTAO,
              AV.TXCOMPLEMENTOQUESTAO,
              AV.NRTEMAANALISE,
              CASE WHEN AV.NMTEMAANALISE IS NULL THEN 'Geral' ELSE AV.NMTEMAANALISE END AS NMTEMAANALISE,
              CASE WHEN AV.SGTEMAANALISE IS NULL THEN 'GER' ELSE AV.SGTEMAANALISE END AS SGTEMAANALISE,
              AV.TXPALAVRACHAVE,
   
              -- LOCAL DE AVALIAO
              AV.NRLOCALAVALIACAO,
              AV.NMLOCALAVALIACAO,
              AV.SGLOCALAVALIACAO,
   
              -- ITEM DE AVALIAO
              AV.NRITEMAVALIACAO,
              AV.NMITEMAVALIACAO,
              AV.SGITEMAVALIACAO,
   
              -- AVALIAO
              AV.NRAVALIACAO,
              AV.DTREFEAVALIACAO,
              TO_DATE('01'||TO_CHAR(AV.DTREFEAVALIACAO,'MMYYYY'),'DDMMYYYY') DTMETAMES,
              AV.QTPREVPARTICAVAL,
              AV.IDSITUACAOAVALIACAO,
              AV.DTINCLUSAO,
              AV.CDOPERINCLUSAO,
   
              -- META POR MS
              ME.VRPEPARTICIPACAO METAPEPARTICIPACAO,
              ME.VRPESATISFACAO METAPESATISFACAO,
   
              -- AVALIAO   
              TA.QTREALPARTICAVAL,
              TA.VRMAIORPESORESPOSTA,
              TA.VRPESOTOTALAVALIACAO,
              CASE WHEN (TA.VRMAIORPESORESPOSTA * TA.QTREALPARTICAVAL) <> 0
                   THEN (TA.VRMAIORPESORESPOSTA * TA.QTREALPARTICAVAL)
                   ELSE 0
                    END AS VRPESOIDEALAVALIACAO,
                    
              CASE WHEN AV.QTPREVPARTICAVAL <> 0
                   THEN TA.QTREALPARTICAVAL / AV.QTPREVPARTICAVAL * 100
                   ELSE 0
                    END AS VRPEPARTICIPACAO,
              CASE WHEN (TA.VRMAIORPESORESPOSTA * TA.QTREALPARTICAVAL) <> 0
                   THEN TA.VRPESOTOTALAVALIACAO / (TA.VRMAIORPESORESPOSTA * TA.QTREALPARTICAVAL) * 100
                   ELSE 0
                    END AS VRPESATISFACAO,
                    
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 1 THEN AV.DSRESPOSTA ELSE '' END) ||
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 2 THEN AV.DSRESPOSTA ELSE '' END) ||
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 3 THEN AV.DSRESPOSTA ELSE '' END) ||
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 4 THEN AV.DSRESPOSTA ELSE '' END) ||
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 5 THEN AV.DSRESPOSTA ELSE '' END) RESPOSTAS,
              
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 1 THEN AV.DSRESPOSTA ELSE NULL END) RESPOSTA1,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 2 THEN AV.DSRESPOSTA ELSE NULL END) RESPOSTA2,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 3 THEN AV.DSRESPOSTA ELSE NULL END) RESPOSTA3,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 4 THEN AV.DSRESPOSTA ELSE NULL END) RESPOSTA4,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 5 THEN AV.DSRESPOSTA ELSE NULL END) RESPOSTA5,
              
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 1 THEN AV.VRPESORESPOSTA ELSE NULL END) VRPESORESPOSTA1,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 2 THEN AV.VRPESORESPOSTA ELSE NULL END) VRPESORESPOSTA2,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 3 THEN AV.VRPESORESPOSTA ELSE NULL END) VRPESORESPOSTA3,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 4 THEN AV.VRPESORESPOSTA ELSE NULL END) VRPESORESPOSTA4,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 5 THEN AV.VRPESORESPOSTA ELSE NULL END) VRPESORESPOSTA5,
              
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 1 THEN AV.QTRESPQUESAVAL ELSE NULL END) QTDE_RESPOSTA1,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 2 THEN AV.QTRESPQUESAVAL ELSE NULL END) QTDE_RESPOSTA2,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 3 THEN AV.QTRESPQUESAVAL ELSE NULL END) QTDE_RESPOSTA3,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 4 THEN AV.QTRESPQUESAVAL ELSE NULL END) QTDE_RESPOSTA4,
              MAX(CASE WHEN AV.NRCONTADOR_RESPOSTA = 5 THEN AV.QTRESPQUESAVAL ELSE NULL END) QTDE_RESPOSTA5
         FROM (SELECT FI.NRORG,
                      -- FILIAL
                      FI.CDFILIAL,
                      FI.NMFILIAL,
                      FI.NMSUPERVISOR,
   
                      -- QUESTIONRIO MODELO
                      PA.NRPADRAVALIACAO,
                      PA.NMPADRAVALIACAO,
   
                      -- QUESTO
                      QU.NRQUESTAO,
                      QU.TXQUESTAO,
                      RA.TXCOMPLEMENTOQUESTAO,
                      RA.NRTEMAANALISE,
                      TA.NMTEMAANALISE,
                      TA.SGTEMAANALISE,
                      QU.TXPALAVRACHAVE,
   
                      -- LOCAL DE AVALIAO
                      LA.NRLOCALAVALIACAO,
                      LA.NMLOCALAVALIACAO,
                      LA.SGLOCALAVALIACAO,
   
                      -- ITEM DE AVALIAO
                      IA.NRITEMAVALIACAO,
                      IA.NMITEMAVALIACAO,
                      IA.SGITEMAVALIACAO,
   
                      -- AVALIAO
                      AG.NRAVALIACAO,
                      RA.DTEXECUCAOAVAL DTREFEAVALIACAO,
                      AG.QTPREVPARTICAVAL,
                      AG.IDSITUACAOAVALIACAO,
                      AG.DTINCLUSAO,
                      AG.CDOPERINCLUSAO,
                      RE.NRRESPOSTA,
                      RE.DSRESPOSTA,
                      RE.VRPESORESPOSTA,
                      RA.QTRESPQUESAVAL,
                      (SUM(1) OVER (PARTITION BY AG.NRAVALIACAO, QU.NRQUESTAO, RA.TXCOMPLEMENTOQUESTAO, RA.NRTEMAANALISE
                                        ORDER BY AG.NRAVALIACAO, QU.NRQUESTAO, RA.TXCOMPLEMENTOQUESTAO, RA.NRTEMAANALISE, RE.NRORDENARESPOST
                                         ROWS BETWEEN UNBOUNDED PRECEDING AND CURRENT ROW)) NRCONTADOR_RESPOSTA
                 FROM AVALIACAOGERAL AG
                INNER JOIN
                     (SELECT FI.NRORG, FI.CDFILIAL, FI.NMFILIAL, OP.NMOPERADOR NMSUPERVISOR
                         FROM FILIAL FI
                         LEFT JOIN
                              OPERADOR OP
                           ON OP.CDOPERADOR = FI.CDSUPERVISOR
                          AND OP.NRORG = FI.NRORG
                        WHERE FI.NRORG = P_NRORG
                          AND (NVL(P_CDGRUPFILI, 'T') = 'T' AND (FI.CDFILIAL = P_CDFILIAL OR NVL(P_CDFILIAL, 'T') = 'T'))
                           OR EXISTS
                              (SELECT *
                                 FROM FILGRUPFILI FG
                                WHERE FG.NRORG = P_NRORG
                                  AND FG.CDGRUPFILI = P_CDGRUPFILI
                                  AND FG.CDFILIAL = FI.CDFILIAL)) FI
                   ON FI.CDFILIAL = AG.CDFILIAL
                  AND FI.NRORG = AG.NRORG
                INNER JOIN
                      PADRAVALIACAO PA
                   ON PA.NRPADRAVALIACAO = AG.NRPADRAVALIACAO
                  AND PA.NRORG = AG.NRORG
                INNER JOIN
                      (SELECT E.NRORG, E.NRAVALIACAO, TRUNC(E.DTEXECUCAOAVAL) DTEXECUCAOAVAL, E.TXCOMPLEMENTOQUESTAO, E.NRTEMAANALISE, R.NRRESPOSTA, COUNT(*) QTRESPQUESAVAL
                         FROM RESPAVALIACAO R, EXECAVALIACAO E
                        WHERE E.NRORG = P_NRORG
                          AND E.DTEXECUCAOAVAL BETWEEN P_DATA_INICIAL AND P_DATA_FINAL
                          AND R.NRORG = E.NRORG
                          AND R.NREXECAVALIACAO = E.NREXECAVALIACAO
                          AND R.NRRESPOSTA IS NOT NULL
                        GROUP BY E.NRORG, E.NRAVALIACAO, TRUNC(E.DTEXECUCAOAVAL), E.TXCOMPLEMENTOQUESTAO, E.NRTEMAANALISE, R.NRRESPOSTA) RA
                   ON RA.NRAVALIACAO = AG.NRAVALIACAO
                  AND RA.NRORG = AG.NRORG
                INNER JOIN
                      RESPOSTA RE
                   ON RE.NRRESPOSTA = RA.NRRESPOSTA
                  AND RE.NRORG = RA.NRORG
                INNER JOIN
                      QUESTAO QU
                   ON QU.NRQUESTAO = RE.NRQUESTAO
                  AND QU.NRORG = RE.NRORG
                 LEFT JOIN
                      AVL_TEMAANALISE TA
                   ON TA.NRTEMAANALISE = RA.NRTEMAANALISE
                  AND TA.NRORG = RA.NRORG
                 LEFT JOIN
                      AVL_LOCALAVALIACAO LA
                   ON LA.NRLOCALAVALIACAO = AG.NRLOCALAVALIACAO
                  AND LA.NRORG = AG.NRORG
                 LEFT JOIN
                      AVL_ITEMAVALIACAO IA
                   ON IA.NRITEMAVALIACAO = AG.NRITEMAVALIACAO
                  AND IA.NRORG = AG.NRORG
                WHERE AG.NRORG = P_NRORG
                  AND AG.IDSITUACAOAVALIACAO <> 'CANCELADA'
                  AND AG.IDSITUACAOAVALIACAO IN (V_PENDENTE, V_CONCLUIDA)) AV
         LEFT JOIN
              AVL_METAMES ME
           ON ME.DTMETAMES = TO_DATE('01'||TO_CHAR(AV.DTREFEAVALIACAO,'MMYYYY'),'DDMMYYYY')
          AND ME.NRORG = P_NRORG
        INNER JOIN
              -- TOTAL DE PARTICIPANTES, MAIOR PESO ENTRE AS RESPOSTAS E PESO TOTAL APURADO NA AVALIAO
              -- INFORMAES ORIUNDAS DO RESUMO COM A QUANTIDADE DE VOTOS POR RESPOSTA
              (SELECT AG.NRAVALIACAO, RE.NRQUESTAO, RA.TXCOMPLEMENTOQUESTAO, RA.NRTEMAANALISE,
                      SUM(RA.QTRESPQUESAVAL) QTREALPARTICAVAL,
                      MAX(RE.VRPESORESPOSTA) VRMAIORPESORESPOSTA,
                      SUM(RE.VRPESORESPOSTA * RA.QTRESPQUESAVAL) VRPESOTOTALAVALIACAO
                 FROM (SELECT AG.CDFILIAL, AG.NRORG, AG.NRAVALIACAO, COUNT(*)
                         FROM AVALIACAOGERAL AG, EXECAVALIACAO EX 
                        WHERE AG.NRORG = P_NRORG 
                          AND EX.NRORG = AG.NRORG 
                          AND EX.NRAVALIACAO = AG.NRAVALIACAO 
                          AND EX.DTEXECUCAOAVAL BETWEEN P_DATA_INICIAL AND P_DATA_FINAL
                        GROUP BY AG.CDFILIAL, AG.NRORG, AG.NRAVALIACAO) AG
                INNER JOIN
                     (SELECT FI.NRORG, FI.CDFILIAL
                         FROM FILIAL FI
                        WHERE FI.NRORG = P_NRORG
                          AND (NVL(P_CDGRUPFILI, 'T') = 'T' AND (FI.CDFILIAL = P_CDFILIAL OR NVL(P_CDFILIAL, 'T') = 'T'))
                           OR EXISTS
                              (SELECT *
                                 FROM FILGRUPFILI FG
                                WHERE FG.NRORG = P_NRORG
                                  AND FG.CDGRUPFILI = P_CDGRUPFILI
                                  AND FG.CDFILIAL = FI.CDFILIAL)) FI
                   ON FI.CDFILIAL = AG.CDFILIAL
                  AND FI.NRORG = AG.NRORG
                INNER JOIN
                      (SELECT E.NRORG, E.NRAVALIACAO, TRUNC(E.DTEXECUCAOAVAL) DTEXECUCAOAVAL, E.TXCOMPLEMENTOQUESTAO, E.NRTEMAANALISE, R.NRRESPOSTA, COUNT(*) QTRESPQUESAVAL
                         FROM RESPAVALIACAO R, EXECAVALIACAO E
                        WHERE E.NRORG = P_NRORG
                          AND E.DTEXECUCAOAVAL BETWEEN P_DATA_INICIAL AND P_DATA_FINAL
                          AND R.NRORG = E.NRORG
                          AND R.NREXECAVALIACAO = E.NREXECAVALIACAO
                          AND R.NRRESPOSTA IS NOT NULL
                        GROUP BY E.NRORG, E.NRAVALIACAO, TRUNC(E.DTEXECUCAOAVAL), E.TXCOMPLEMENTOQUESTAO, E.NRTEMAANALISE, R.NRRESPOSTA) RA                
                   ON RA.NRAVALIACAO = AG.NRAVALIACAO
                  AND RA.NRORG = AG.NRORG
                INNER JOIN
                      RESPOSTA RE
                   ON RE.NRRESPOSTA = RA.NRRESPOSTA
                  AND RE.NRORG = RA.NRORG
                GROUP BY AG.NRAVALIACAO, RE.NRQUESTAO, RA.TXCOMPLEMENTOQUESTAO, RA.NRTEMAANALISE) TA
           ON TA.NRAVALIACAO = AV.NRAVALIACAO
          AND TA.NRQUESTAO = AV.NRQUESTAO
          AND ((TA.TXCOMPLEMENTOQUESTAO = AV.TXCOMPLEMENTOQUESTAO) OR (TA.TXCOMPLEMENTOQUESTAO IS NULL AND AV.TXCOMPLEMENTOQUESTAO IS NULL))
          AND ((TA.NRTEMAANALISE = AV.NRTEMAANALISE) OR (TA.NRTEMAANALISE IS NULL AND AV.NRTEMAANALISE IS NULL))
        GROUP BY AV.NRORG,
                 AV.CDFILIAL,
                 AV.NMFILIAL,
                 AV.NMSUPERVISOR,
                 AV.NRPADRAVALIACAO,
                 AV.NMPADRAVALIACAO,
                 AV.NRQUESTAO,
                 AV.TXQUESTAO,
                 AV.TXCOMPLEMENTOQUESTAO,
                 AV.NRTEMAANALISE,
                 CASE WHEN AV.NMTEMAANALISE IS NULL THEN 'Geral' ELSE AV.NMTEMAANALISE END,
                 CASE WHEN AV.SGTEMAANALISE IS NULL THEN 'GER' ELSE AV.SGTEMAANALISE END,
                 AV.TXPALAVRACHAVE,
                 AV.NRLOCALAVALIACAO,
                 AV.NMLOCALAVALIACAO,
                 AV.SGLOCALAVALIACAO,
                 AV.NRITEMAVALIACAO,
                 AV.NMITEMAVALIACAO,
                 AV.SGITEMAVALIACAO,
                 AV.NRAVALIACAO,
                 AV.DTREFEAVALIACAO,
                 TO_DATE('01'||TO_CHAR(AV.DTREFEAVALIACAO,'MMYYYY'),'DDMMYYYY'),
                 AV.QTPREVPARTICAVAL,
                 AV.IDSITUACAOAVALIACAO,
                 AV.DTINCLUSAO,
                 AV.CDOPERINCLUSAO,
                 ME.VRPEPARTICIPACAO,
                 ME.VRPESATISFACAO,
                 TA.QTREALPARTICAVAL,
                 TA.VRMAIORPESORESPOSTA,
                 TA.VRPESOTOTALAVALIACAO,
                 CASE WHEN AV.QTPREVPARTICAVAL <> 0
                      THEN TA.QTREALPARTICAVAL / AV.QTPREVPARTICAVAL * 100
                      ELSE 0
                       END,
                 CASE WHEN (TA.VRMAIORPESORESPOSTA * TA.QTREALPARTICAVAL) <> 0
                      THEN TA.VRPESOTOTALAVALIACAO / (TA.VRMAIORPESORESPOSTA * TA.QTREALPARTICAVAL) * 100
                      ELSE 0
                       END);
BEGIN
   V_PENDENTE := ' ';
   V_CONCLUIDA := ' ';
   V_CANCELADA := ' ';
   IF P_SITUACAO_AVALIACAO IN ('PENDENTE', 'T', NULL)  THEN
      V_PENDENTE := 'PENDENTE';
   END IF;
   IF P_SITUACAO_AVALIACAO IN ('CONCLUIDA', 'T', NULL)  THEN
      V_CONCLUIDA := 'CONCLUIDA';
   END IF;
   IF P_SITUACAO_AVALIACAO IN ('CANCELADA')  THEN
      V_CANCELADA := 'CANCELADA';
   END IF;
   OPEN C_AVALIACAO;
   LOOP
      FETCH C_AVALIACAO INTO
         OUT_RECORD.NRORG,
         OUT_RECORD.CDFILIAL,
         OUT_RECORD.NMFILIAL,
         OUT_RECORD.NMSUPERVISOR,
         OUT_RECORD.NRPADRAVALIACAO,
         OUT_RECORD.NMPADRAVALIACAO,
         OUT_RECORD.NRQUESTAO,
         OUT_RECORD.TXQUESTAO,
         OUT_RECORD.TXCOMPLEMENTOQUESTAO,
         OUT_RECORD.NRTEMAANALISE,
         OUT_RECORD.NMTEMAANALISE,
         OUT_RECORD.SGTEMAANALISE,
         OUT_RECORD.TXPALAVRACHAVE,
         OUT_RECORD.NRLOCALAVALIACAO,
         OUT_RECORD.NMLOCALAVALIACAO,
         OUT_RECORD.SGLOCALAVALIACAO,
         OUT_RECORD.NRITEMAVALIACAO,
         OUT_RECORD.NMITEMAVALIACAO,
         OUT_RECORD.SGITEMAVALIACAO ,
         OUT_RECORD.NRAVALIACAO ,
         OUT_RECORD.DTREFEAVALIACAO,
         OUT_RECORD.DTMETAMES,
         OUT_RECORD.QTPREVPARTICAVAL,
         OUT_RECORD.IDSITUACAOAVALIACAO,
         OUT_RECORD.DTINCLUSAO,
         OUT_RECORD.CDOPERINCLUSAO,
         OUT_RECORD.METAPEPARTICIPACAO,
         OUT_RECORD.METAPESATISFACAO,
         OUT_RECORD.QTREALPARTICAVAL,
         OUT_RECORD.VRMAIORPESORESPOSTA,
         OUT_RECORD.VRPESOTOTALAVALIACAO,
         OUT_RECORD.VRPESOIDEALAVALIACAO,
         OUT_RECORD.VRPEPARTICIPACAO,
         OUT_RECORD.VRPESATISFACAO,
         OUT_RECORD.RESPOSTAS,
         OUT_RECORD.RESPOSTA1,
         OUT_RECORD.RESPOSTA2,
         OUT_RECORD.RESPOSTA3,
         OUT_RECORD.RESPOSTA4,
         OUT_RECORD.RESPOSTA5,
         OUT_RECORD.VRPESORESPOSTA1,
         OUT_RECORD.VRPESORESPOSTA2,
         OUT_RECORD.VRPESORESPOSTA3,
         OUT_RECORD.VRPESORESPOSTA4,
         OUT_RECORD.VRPESORESPOSTA5,
         OUT_RECORD.QTDE_RESPOSTA1,
         OUT_RECORD.QTDE_RESPOSTA2,
         OUT_RECORD.QTDE_RESPOSTA3,
         OUT_RECORD.QTDE_RESPOSTA4,
         OUT_RECORD.QTDE_RESPOSTA5;
      EXIT WHEN C_AVALIACAO%NOTFOUND;
      PIPE ROW (OUT_RECORD);
   END LOOP;
   CLOSE C_AVALIACAO;
   RETURN;
END;
/

--SELECT *
--  FROM TABLE (AVL_PESQUISA_OPINIAO (:P_NRORG, :P_CDGRUPFILI, :P_CDFILIAL, :P_DATA_INICIAL, :P_DATA_FINAL))
-- ORDER BY CDFILIAL, DTMETAMES, NMPADRAVALIACAO,
--          TXQUESTAO, TXCOMPLEMENTOQUESTAO, SGTEMAANALISE,
--          DTREFEAVALIACAO, SGLOCALAVALIACAO, SGITEMAVALIACAO

-- VERSAO --
BEGIN ATUVEROBJ('AVL_PESQUISA_OPINIAO','5.55.010'); END;
/

